@@ -203,8 +203,8 @@ impl<'a> MpesaExpressRequestBuilder<'a> {
             password: &password,
             timestamp: &timestamp,
             amount: self.amount.unwrap_or(10),
-            party_a: self.party_a.unwrap_or(self.business_short_code),
-            party_b: self.party_b.unwrap_or(self.phone_number.unwrap_or("None")),
+            party_a: self.party_a.unwrap_or(self.phone_number.unwrap_or("None")),
+            party_b: self.party_b.unwrap_or(self.business_short_code),
             phone_number: self.phone_number.unwrap_or("None"),
             call_back_url: self.callback_url.unwrap_or("None"),
             account_reference: self.account_ref.unwrap_or("None"),
