@@ -10,11 +10,11 @@
 //! 3. [B2C](https://developer.safaricom.co.ke/docs?shell#b2c-api)
 //! 4. [C2B Register](https://developer.safaricom.co.ke/docs?shell#c2b-api)
 //! 5. [C2B Simulate](https://developer.safaricom.co.ke/docs#account-balance-api)
+//! 6. [Mpesa Express/ STK Push](https://developer.safaricom.co.ke/docs#lipa-na-m-pesa-online-payment)
 //!
 //! Also worth noting I am using `reqwest::blocking::Client` to make http requests. Research ongoing
 //! on how to make this crate async.
 
-#![allow(non_snake_case)]
 mod account_balance;
 mod b2b;
 mod b2c;
